@@ -1,26 +1,33 @@
+from __future__ import annotations
+
 import json
-from typing import Any, Callable, Dict, List, Optional, Union
+from typing import Any, Callable
+
 import requests
+
 from meilisearch.config import Config
 from meilisearch.errors import (
     MeiliSearchApiError,
     MeiliSearchCommunicationError,
     MeiliSearchTimeoutError,
 )
+from meilisearch.version import qualified_version
+
 
 class HttpRequests:
     def __init__(self, config: Config) -> None:
         self.config = config
         self.headers = {
             'Authorization': f'Bearer {self.config.api_key}',
+            'User-Agent': qualified_version(),
         }
 
     def send_request(
         self,
         http_method: Callable,
         path: str,
-        body: Optional[Union[Dict[str, Any], List[Dict[str, Any]], List[str], str]] = None,
-        content_type: Optional[str] = None,
+        body: dict[str, Any] | list[dict[str, Any]] | list[str] | str | None = None,
+        content_type: str | None = None,
     ) -> Any:
         if content_type:
             self.headers['Content-Type'] = content_type
@@ -55,31 +62,31 @@ class HttpRequests:
     def post(
         self,
         path: str,
-        body: Optional[Union[Dict[str, Any], List[Dict[str, Any]], List[str], str]] = None,
-        content_type: Optional[str] = 'application/json',
+        body: dict[str, Any] | list[dict[str, Any]] | list[str] | str | None = None,
+        content_type: str | None = 'application/json',
     ) -> Any:
         return self.send_request(requests.post, path, body, content_type)
 
     def patch(
         self,
         path: str,
-        body: Optional[Union[Dict[str, Any], List[Dict[str, Any]], List[str], str]] = None,
-        content_type: Optional[str] = 'application/json',
+        body: dict[str, Any] | list[dict[str, Any]] | list[str] | str | None = None,
+        content_type: str | None = 'application/json',
     ) -> Any:
         return self.send_request(requests.patch, path, body, content_type)
 
     def put(
         self,
         path: str,
-        body: Optional[Union[Dict[str, Any], List[Dict[str, Any]], List[str]]] = None,
-        content_type: Optional[str] = 'application/json',
+        body: dict[str, Any] | list[dict[str, Any]] | list[str] | None = None,
+        content_type: str | None = 'application/json',
     ) -> Any:
         return self.send_request(requests.put, path, body, content_type)
 
     def delete(
         self,
         path: str,
-        body: Optional[Union[Dict[str, Any], List[Dict[str, Any]], List[str]]] = None,
+        body: dict[str, Any] | list[dict[str, Any]] | list[str] | None = None,
     ) -> Any:
         return self.send_request(requests.delete, path, body)
 
