@@ -1,4 +1,4 @@
-from typing import Optional
+from __future__ import annotations
 
 
 class Config:
@@ -25,13 +25,16 @@ class Config:
         accept_new_fields = 'accept-new-fields'
         filterable_attributes = 'filterable-attributes'
         sortable_attributes = 'sortable-attributes'
+        typo_tolerance = 'typo-tolerance'
         dumps = 'dumps'
+        pagination = 'pagination'
+        faceting = 'faceting'
 
     def __init__(
         self,
         url: str,
-        api_key: Optional[str] = None,
-        timeout: Optional[int] = None
+        api_key: str | None = None,
+        timeout: int | None = None
     ) -> None:
         """
         Parameters
