@@ -143,8 +143,8 @@ class Index():
         -------
         tasks:
         TaskResults instance with attributes:
-            - from_
-            - next_
+            - from
+            - next
             - limit
             - results : list of Task instances containing all enqueued, processing, succeeded or failed tasks of the index
 
@@ -264,7 +264,7 @@ class Index():
             body=body
         )
 
-    def get_document(self, document_id: str, parameters: dict[str, Any] | None = None) -> Document:
+    def get_document(self, document_id: str | int, parameters: dict[str, Any] | None = None) -> Document:
         """Get one document with given document identifier.
 
         Parameters
@@ -573,7 +573,7 @@ class Index():
 
         return tasks
 
-    def delete_document(self, document_id: str) -> TaskInfo:
+    def delete_document(self, document_id: str | int) -> TaskInfo:
         """Delete one document from the index.
 
         Parameters
@@ -597,7 +597,7 @@ class Index():
         )
         return TaskInfo(**response)
 
-    def delete_documents(self, ids: list[str]) -> TaskInfo:
+    def delete_documents(self, ids: list[str | int]) -> TaskInfo:
         """Delete multiple documents from the index.
 
         Parameters
@@ -618,7 +618,7 @@ class Index():
         """
         response = self.http.post(
             f'{self.config.paths.index}/{self.uid}/{self.config.paths.document}/delete-batch',
-            ids
+            [str(i) for i in ids]
         )
         return TaskInfo(**response)
 
