@@ -1,6 +1,10 @@
-from typing import Any, List, Dict, Optional
+from __future__ import annotations
+
+from typing import Any, Dict, Optional
+
 from camel_converter.pydantic_base import CamelBase
 
+
 class Task(CamelBase):
     uid: str
     index_uid: str
@@ -25,7 +29,7 @@ class TaskInfo(CamelBase):
 
 class TaskResults:
     def __init__(self, resp: Dict[str, Any]) -> None:
-        self.results: List[Task] = [Task(**task) for task in resp['results']]
+        self.results: list[Task] = [Task(**task) for task in resp['results']]
         self.limit: int = resp['limit']
         self.from_: int = resp['from']
         self.next_: int = resp['next']
